
Changelog
=========

0.1.0 (2014-01-01)
------------------

* First release on PyPI.

0.3.0 (?)
------------------

* Fixed exception handling on Python 3.

0.5.0 (2014-10-04)
------------------

* Made addError handle exceptions the same way as addFailure.

0.6.0 (2015-09-06)
------------------

* Added Error column.
* Changed Fail/Error columns to be colored if there is a failure/error.
